/* FilePropertyDialog.java $Revision:$  $Date:$
 *
 * Copyright (C) 2001  Mike Swainston-Rainford
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.togethersoft.modules.p4vcs.dialogs;

import com.perforce.api.FileEntry;
import com.togethersoft.modules.p4vcs.PerforceVcsProvider;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Vector;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.border.BevelBorder;
import javax.swing.border.SoftBevelBorder;

/**
 * This class defines is a hack dialog for file property display needs reworking
 * @author <a href="mailto:mike@mjs-r.com">Mike Swainston-Rainford</a>
 * @version $Date:$ $Revision:$
 */
public class FilePropertyDialog extends JDialog
{
   /** Creates new form FilePropertyDialog */
   public FilePropertyDialog(JDialog parent, boolean modal, FileEntry fent, PerforceVcsProvider provider)
   {
      super(parent, modal);
      this.fent = fent;
      this.provider = provider;
      initDialog();
   }

   public void initDialog()
   {
      initComponents();
      DepotTextField.setText(fent.getDepotPath());
      clientTextField.setText(fent.getClientPath());
      headActionTextField.setText(fent.getHeadAction());
      headChangeTextField.setText("" + fent.getHeadChange());
      headRevTextField.setText("" + fent.getHeadRev());
      fileTypeTextField.setText(fent.getHeadType());
      haveRevTextField.setText("" + fent.getHaveRev());
      lastModTextField.setText(fent.getHeadDate());
      if (fent.isOurLock())
         lockedByTextField.setText(provider.getP4UserEmail());
      StringBuffer otherText = new StringBuffer();
      if (! "".equals(fent.getChange()))
      {
         String myChange = fent.getChange();
         if (myChange.equals("default"))
            myChange = myChange + " change";
         else
            myChange = "change " + myChange;
         otherText.append(provider.getP4UserEmail() + " - " + myChange + " (" + fent.getAction() + ")\n");
      }
      Vector others = null;
      if (fent.getOther() > 0)
      {
         others = fent.getOthers();
         for (int i = 0; i < others.size(); i++)
         {
            String[] other = (String[]) others.get(i);
            otherText = otherText.append(other[0] + " - (");
            otherText = otherText.append(other[1] + ")\n");
            if (fent.isOtherLock() && i == 0)
            {
               //to do what if not first owner has locked it?
               lockedByTextField.setText(other[0]);
            }
         }
      }
      openedTextArea.setText(otherText.toString());
      Dimension dimension = getContentPane().getSize();
      Dimension dimension1 = Toolkit.getDefaultToolkit().getScreenSize();
      setLocation((dimension1.width - dimension.width) / 2, (dimension1.height - dimension.height) / 2);
      pack();
   }

   /**
    * This method is called from within the constructor to initialize the form.
    * WARNING: Do NOT modify this code. The content of this method is always regenerated by the Form Editor.
    */
   private void initComponents()
   { //GEN-BEGIN:initComponents
      mainPanel = new JPanel();
      clientLabel = new JLabel();
      headActionTextField = new JTextField();
      headChangeLabel = new JLabel();
      DepotLabel = new JLabel();
      DepotTextField = new JTextField();
      fileTypeLabel = new JLabel();
      haveRevLabel = new JLabel();
      openedByLabel = new JLabel();
      clientTextField = new JTextField();
      lockedByTextField = new JTextField();
      headRevLabel = new JLabel();
      headActionLabel = new JLabel();
      fileTypeTextField = new JTextField();
      headChangeTextField = new JTextField();
      headRevTextField = new JTextField();
      haveRevTextField = new JTextField();
      lastModTimeLabel = new JLabel();
      lastModTextField = new JTextField();
      closeButton = new JButton();
      lockedByLabel = new JLabel();
      openedTextArea = new JTextArea();
      mainPanel.setLayout(new GridBagLayout());
      GridBagConstraints gridBagConstraints1;
      setResizable(false);
      mainPanel.setBackground(new Color(212, 208, 200));
      setModal(true);
      setTitle("File Information");
      addWindowListener(
          new WindowAdapter()
          {
             public void windowClosing(WindowEvent evt)
             {
                closeDialog(evt);
             }
          });
      clientLabel.setText("Client Path:");
      clientLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 2;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 26;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 0);
      mainPanel.setPreferredSize(new java.awt.Dimension(501, 414));
      mainPanel.setSize(new java.awt.Dimension(501,364));
      mainPanel.setMinimumSize(new java.awt.Dimension(501, 414));
      mainPanel.add(clientLabel, gridBagConstraints1);
      headActionTextField.setEditable(false);
      headActionTextField.setBackground(new Color(212, 208, 200));
      headActionTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 10;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 64;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(5, 10, 0, 0);
      mainPanel.add(headActionTextField, gridBagConstraints1);
      headChangeLabel.setText("Head Change:");
      headChangeLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 11;
      gridBagConstraints1.gridy = 10;
      gridBagConstraints1.gridwidth = 2;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 12;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(5, 20, 0, 0);
      mainPanel.add(headChangeLabel, gridBagConstraints1);
      DepotLabel.setText("Depot Path:");
      DepotLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 0;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 25;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 0);
      mainPanel.add(DepotLabel, gridBagConstraints1);
      DepotTextField.setEditable(false);
      DepotTextField.setBackground(new Color(212, 208, 200));
      DepotTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      DepotTextField.setPreferredSize(new java.awt.Dimension(364,25));
      DepotTextField.setSize(new java.awt.Dimension(364,25));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 0;
      gridBagConstraints1.gridwidth = 7;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 274;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 10);
      mainPanel.add(DepotTextField,
          new GridBagConstraints(8, 0, 7, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.BOTH,
          new Insets(10, 10, 0, 10), 274, 3));
      fileTypeLabel.setText("File Type:");
      fileTypeLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 4;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 38;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(20, 10, 0, 0);
      mainPanel.add(fileTypeLabel, gridBagConstraints1);
      haveRevLabel.setText("Have Revision:");
      haveRevLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 11;
      gridBagConstraints1.gridy = 6;
      gridBagConstraints1.gridwidth = 2;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 8;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(5, 20, 0, 0);
      mainPanel.add(haveRevLabel, gridBagConstraints1);
      openedByLabel.setText("Opened By:");
      openedByLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 16;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 26;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(20, 10, 0, 0);
      mainPanel.add(openedByLabel, gridBagConstraints1);
      clientTextField.setEditable(false);
      clientTextField.setBackground(new Color(212, 208, 200));
      clientTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 2;
      gridBagConstraints1.gridwidth = 7;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 274;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 10);
      mainPanel.add(clientTextField, gridBagConstraints1);
      lockedByTextField.setEditable(false);
      lockedByTextField.setBackground(new Color(212, 208, 200));
      lockedByTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 17;
      gridBagConstraints1.gridwidth = 7;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 274;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(20, 10, 0, 10);
      mainPanel.add(lockedByTextField, gridBagConstraints1);
      headRevLabel.setText("Head Revision:");
      headRevLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 6;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 7;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(5, 10, 0, 0);
      mainPanel.add(headRevLabel, gridBagConstraints1);
      headActionLabel.setText("Head Action:");
      headActionLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 10;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 19;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(5, 10, 0, 0);
      mainPanel.add(headActionLabel, gridBagConstraints1);
      fileTypeTextField.setEditable(false);
      fileTypeTextField.setBackground(new Color(212, 208, 200));
      fileTypeTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 4;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 64;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(20, 10, 0, 0);
      mainPanel.add(fileTypeTextField, gridBagConstraints1);
      headChangeTextField.setEditable(false);
      headChangeTextField.setBackground(new Color(212, 208, 200));
      headChangeTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 14;
      gridBagConstraints1.gridy = 10;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 64;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(5, 30, 0, 10);
      mainPanel.add(headChangeTextField, gridBagConstraints1);
      headRevTextField.setEditable(false);
      headRevTextField.setBackground(new Color(212, 208, 200));
      headRevTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 6;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 64;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(5, 10, 0, 0);
      mainPanel.add(headRevTextField, gridBagConstraints1);
      haveRevTextField.setEditable(false);
      haveRevTextField.setBackground(new Color(212, 208, 200));
      haveRevTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 14;
      gridBagConstraints1.gridy = 6;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 64;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(5, 30, 0, 10);
      mainPanel.add(haveRevTextField, gridBagConstraints1);
      lastModTimeLabel.setText("Last ModTime:");
      lastModTimeLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 14;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 7;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 0);
      mainPanel.add(lastModTimeLabel, gridBagConstraints1);
      lastModTextField.setEditable(false);
      lastModTextField.setBackground(new Color(212, 208, 200));
      lastModTextField.setBorder(new SoftBevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 14;
      gridBagConstraints1.gridwidth = 7;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 274;
      gridBagConstraints1.ipady = -3;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 10);
      mainPanel.add(lastModTextField, gridBagConstraints1);
      closeButton.setText("Close");
      closeButton.setBackground(new Color(212, 208, 200));
      //closeButton.setBorder(new javax.swing.border.BevelBorder(javax.swing.border.BevelBorder.RAISED));
      closeButton.addActionListener(
          new ActionListener()
          {
             public void actionPerformed(ActionEvent evt)
             {
                closeButtonActionPerformed(evt);
             }
          });
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 12;
      gridBagConstraints1.gridy = 19;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 23;
      gridBagConstraints1.insets = new Insets(10, 0, 10, 0);
      mainPanel.add(closeButton, gridBagConstraints1);
      lockedByLabel.setText("Locked By:");
      lockedByLabel.setFont(new Font("Arial", 0, 11));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 0;
      gridBagConstraints1.gridy = 17;
      gridBagConstraints1.fill = GridBagConstraints.BOTH;
      gridBagConstraints1.ipadx = 28;
      gridBagConstraints1.ipady = 3;
      gridBagConstraints1.insets = new Insets(20, 10, 0, 0);
      mainPanel.add(lockedByLabel, gridBagConstraints1);
      openedTextArea.setBackground(new Color(212, 208, 200));
      openedTextArea.setBorder(new BevelBorder(BevelBorder.LOWERED));
      gridBagConstraints1 = new GridBagConstraints();
      gridBagConstraints1.gridx = 8;
      gridBagConstraints1.gridy = 15;
      gridBagConstraints1.gridwidth = 7;
      gridBagConstraints1.gridheight = 2;
      gridBagConstraints1.ipadx = 330;
      gridBagConstraints1.ipady = 20;
      gridBagConstraints1.insets = new Insets(10, 10, 0, 10);
      JPanel panel = new JPanel(new BorderLayout(0, 17));
      panel.add(new JScrollPane(openedTextArea), BorderLayout.CENTER);
      panel.setBorder(BorderFactory.createEmptyBorder(11, 0, 0, 0));
      mainPanel.add(panel, gridBagConstraints1);
      //getContentPane().add(openedTextArea, gridBagConstraints1);
      getContentPane().add(mainPanel, java.awt.BorderLayout.CENTER);
   } //GEN-END:initComponents

   private void closeButtonActionPerformed(ActionEvent evt)
   { //GEN-FIRST:event_closeButtonActionPerformed
      closeDialog(null);
   } //GEN-LAST:event_closeButtonActionPerformed

   /** Closes the dialog */
   private void closeDialog(WindowEvent evt)
   { //GEN-FIRST:event_closeDialog
      setVisible(false);
      dispose();
   } //GEN-LAST:event_closeDialog

   /** @param args the command line arguments */

  /*public static void main(String args[]) {
   new FilePropertyDialog(new java.awt.Frame(), true).show();
   }*/

   // Variables declaration - do not modify//GEN-BEGIN:variables
   private JLabel clientLabel;
   private JTextField headActionTextField;
   private JLabel headChangeLabel;
   private JLabel DepotLabel;
   private JTextField DepotTextField;
   private JLabel fileTypeLabel;
   private JLabel haveRevLabel;
   private JLabel openedByLabel;
   private JTextField clientTextField;
   private JTextField lockedByTextField;
   private JLabel headRevLabel;
   private JLabel headActionLabel;
   private JTextField fileTypeTextField;
   private JTextField headChangeTextField;
   private JTextField headRevTextField;
   private JTextField haveRevTextField;
   private JLabel lastModTimeLabel;
   private JTextField lastModTextField;
   private JButton closeButton;
   private JLabel lockedByLabel;
   private JTextArea openedTextArea;
   private JPanel mainPanel;
   // End of variables declaration//GEN-END:variables
   private FileEntry fent;
   private PerforceVcsProvider provider;
}
